*************************************************************************************************************
* arra_highway_irfs.do
* by Valerie Ramey for "Macroeconomic Consequences of Infrastructure Investment"
* -- Ramey irfs using Leduc and Wilson data with Chodorow-Reich controls merged in    

* Produces Figures 6 and 7 of the paper
*  Also contains code for some other investigations
*************************************************************************************************************
clear all
cap log close
set more off
pause on

set scheme s1color


********************************************************************************
* Load the Leduc-Wilson annual data and merge in Chodorow-Reich controls for employment
********************************************************************************

use LW-master_flypaperSubmitted.dta, clear

merge 1:1 state year using crcontrols.dta, nogen

sort statecode year


global controls "YPHpc gopgovl Perc_Dem_House Perc_Dem_Senate"
global S1_controls "S1.YPHpc S1.gopgovl S1.Perc_Dem_House S1.Perc_Dem_Senate L1S10_Shighway_grosspc"
global S2_controls "S2.YPHpc S2.gopgovl S2.Perc_Dem_House S2.Perc_Dem_Senate"
global F2S4_controls "F2S4.YPHpc F2S4.gopgovl F2S4.Perc_Dem_House F2S4.Perc_Dem_Senate"
global road_factors "im_lanemilespc im_paypc"
global poli_factors "frac_house_committee frac_house_maj house_tenure frac_senate_committee frac_senate_maj senate_tenure"
global L1_road_factors "L.im_lanemilespc L.im_paypc"
global L1_poli_factors "L.frac_house_committee L.frac_house_maj L.house_tenure L.frac_senate_committee L.frac_senate_maj L.senate_tenure"
global L1_all_factors "L.im_lanemilespc L.im_paypc L.ln_total_miles_1944_planpc"


foreach name in oblig_ARRApc outlays_ARRApc apport_ARRApc apportpc outlayspc obligpc{

	replace FHWA_`name'= 0 if FHWA_`name'==.
	gen cumadd_0910_FHWA_`name' = 0
	gen cumadd_0912_FHWA_`name' = 0
	replace cumadd_0910_FHWA_`name' = l.FHWA_`name' + FHWA_`name' -2*l2.FHWA_`name'  if year==2010
	replace cumadd_0912_FHWA_`name' = l.FHWA_`name'+ FHWA_`name'+ F.FHWA_`name' + F2.FHWA_`name'-4*l2.FHWA_`name' if year==2010
}


foreach lag of num 1/2 {

  gen L`lag'_FHWA_oblig_ARRApc = L`lag'.FHWA_oblig_ARRApc
  gen L`lag'_FHWA_outlays_ARRApc = L`lag'.FHWA_outlays_ARRApc
  gen L`lag'_FHWA_apport_ARRApc = L`lag'.FHWA_apport_ARRApc
  gen L`lag'_FHWA_obligpc = L`lag'.FHWA_obligpc
  gen L`lag'_FHWA_outlayspc = L`lag'.FHWA_outlayspc
  gen S`lag'_Shighway_grosspc = S`lag'.Shighway_grosspc
  gen S`lag'_cum_FHWA_oblig_ARRApc = S`lag'.cum_FHWA_oblig_ARRApc
  gen S`lag'_FHWA_apportpc = S`lag'.FHWA_apportpc
  gen S`lag'_FHWA_outlayspc = S`lag'.FHWA_outlayspc
  gen S`lag'_FHWA_obligpc = S`lag'.FHWA_obligpc
  }
  
 
gen L2S10_Shighway_grosspc = L2S10.Shighway_grosspc
gen L1S10_Shighway_grosspc = L1S10.Shighway_grosspc
gen L1_FHWA_apportpc = L1.FHWA_apportpc
gen L2_Shighway_grosspc = L2.Shighway_grosspc
gen cumadd_0912_Shighway_grosspc= L1.Shighway_grosspc+Shighway_grosspc+F1.Shighway_grosspc+F2.Shighway_grosspc-4*L2.Shighway_grosspc if year ==2010
gen ln_total_miles_1944_planpc = ln(total_miles_1944_planpc)
label var ln_total_miles_1944_planpc "Total highway miles per capita in 1944 Proposal (log scale)"
gen L_ln_total_miles_1944_planpc = L.ln_total_miles_1944_planpc
gen LS_FHWA_apportpc = LS.FHWA_apportpc
gen LS_FHWA_obligpc = LS.FHWA_obligpc
gen Shighway_share = Shighway_gross/stateg
gen ln_cum_FHWA_outlays_ARRApc = ln(cum_FHWA_outlays_ARRApc)
gen ln_cum_FHWA_oblig_ARRApc = ln(cum_FHWA_oblig_ARRApc)
gen ln_L1_FHWA_apport_ARRApc = ln(L1_FHWA_apport_ARRApc)

foreach factor in stp_lanemiles stp_vmt stp_pay {
  egen `factor'_natl = total(`factor'), by(year)
  gen `factor'_shr = `factor'/`factor'_natl
  }
  
egen STP_apport_natl = total(STP_apport), by(year)
gen sim_instrument = (0.25*stp_lanemiles_shr + 0.4*stp_vmt_shr + 0.35*stp_pay_shr)*STP_apport_natl/(population/1000)

egen natl_FHWA_apport = sum(FHWA_apport), by(year)
egen natl_FHWA_oblig = sum(FHWA_oblig), by(year)
egen natl_FHWA_outlays = sum(FHWA_outlays), by(year)
egen natl_FHWA_apport_ARRA = sum(FHWA_apport_ARRA), by(year)
egen natl_FHWA_oblig_ARRA = sum(FHWA_oblig_ARRA), by(year)
egen natl_FHWA_outlays_ARRA = sum(FHWA_outlays_ARRA), by(year)
egen natl_Shighway = sum(Shighway_gross), by(year)
egen natl_Seduc_gross = sum(Seduc_gross), by(year)
egen natl_pop = sum(population/1000), by(year)
gen natl_FHWA_apportpc = natl_FHWA_apport/natl_pop
gen natl_FHWA_obligpc = natl_FHWA_oblig/natl_pop
gen natl_FHWA_outlayspc = natl_FHWA_outlays/natl_pop
gen natl_FHWA_apport_ARRApc = natl_FHWA_apport_ARRA/natl_pop
gen natl_FHWA_oblig_ARRApc = natl_FHWA_oblig_ARRA/natl_pop
gen natl_FHWA_outlays_ARRApc = natl_FHWA_outlays_ARRA/natl_pop
gen natl_Shighway_grosspc = natl_Shighway/natl_pop



tempfile dataset_inc_AK_NE
tempfile dataset_exc_AK_NE
save `dataset_inc_AK_NE', replace
	tab year
drop if state=="AK" | state=="NE"
save `dataset_exc_AK_NE', replace

estimates clear

replace YPHpc= YPHpc/1000

* Creating Share variables
replace contributions=0 if contributions ==.
replace cum_FHWA_oblig_ARRApc = FHWA_oblig_ARRApc + L.FHWA_oblig_ARRApc if year==2010

gen lpop = ln(population)

/*Ramey notes

 S12ces_sa_pc1208_n control significant and affects results.
 These two extra CR controls are not significant in emp regressions, either jointly or solely
local controls LS.roadconstruction_emp_pc ces_sa_pc_n S12ces_sa_pc1208_n L12DGSPR_gspr_n 
*/

/* the extra LW controls don't change results and are not significant in the employment irfs */

 local controls_lw S.gopgovl S.Perc_Dem_House S.Perc_Dem_Senate 

* standard errors lower for unweighted using the 3 instruments (current values of "all_factors")

gen h = _n + 2008  /* for irf graphs */

gen ARRA_Obligations = FHWA_oblig_ARRApc
gen ARRA_Outlays = FHWA_outlays_ARRApc
gen Total_Highway_Spending = Shighway_grosspc

* The apport, oblig, spending variables are $ per capita
*  The roadconstruction_emp_pc variable is employment per 1,000 people
* Change units so that coefficients for employment are "jobs per $1 million apportioned"
gen Highway_Employment = roadconstruction_emp_pc*1000


global road_factors "im_lanemilespc im_paypc"

* This shows that ARRA apportionments are predicted by highway employment change between 2007 and 2008
 reg FHWA_apport_ARRApc im_lanemilespc im_paypc LS.Highway_Employment if year==2009, robust
 
 ** For other investigations
*local controls_vr LS.roadconstruction_emp_pc S12ces_sa_pc1208_n 



** Use this for Figure 6
local controls_vr LS.Highway_Employment

** Use this for Figure 7
*local controls_vr LS.Highway_Employment L.lpop

foreach var in ARRA_Obligations ARRA_Outlays Total_Highway_Spending Highway_Employment {

  foreach horiz in S F1S2 F2S3 F3S4 F4S5 {
  
     ivregress gmm `horiz'.`var' (FHWA_apport_ARRApc = $road_factors) ///
          `controls_lw' `controls_vr' if year==2009, robust
	   
	   scalar b_`horiz'_`var'_u = _b[FHWA_apport_ARRApc]
	   scalar se_`horiz'_`var'_u = _se[FHWA_apport_ARRApc] 
	   
	   ivregress gmm `horiz'.`var' (FHWA_apport_ARRApc = $road_factors) ///
          `controls_lw' `controls_vr' [w=population] if year==2009, robust
	   
	   scalar b_`horiz'_`var'_w = _b[FHWA_apport_ARRApc]
	   scalar se_`horiz'_`var'_w = _se[FHWA_apport_ARRApc] 

  }

  * turn coefficients into series
  * all results use the unweighted regressions
  
   foreach wt in u {
   
      matrix define mb_`var'_`wt' = [b_S_`var'_`wt', b_F1S2_`var'_`wt', b_F2S3_`var'_`wt', b_F3S4_`var'_`wt', b_F4S5_`var'_`wt']'
	  matrix define mse_`var'_`wt' = [se_S_`var'_`wt', se_F1S2_`var'_`wt', se_F2S3_`var'_`wt', se_F3S4_`var'_`wt', se_F4S5_`var'_`wt']'
	
	  svmat mb_`var'_`wt', names(b`var'_`wt')
	  svmat mse_`var'_`wt', names(se`var'_`wt')
	  
	  gen up90b`var'_`wt'1 = b`var'_`wt'1 + 1.65*se`var'_`wt'1
	  gen lo90b`var'_`wt'1 = b`var'_`wt'1 - 1.65*se`var'_`wt'1
	  
	  
	  tw (rarea up90b`var'_`wt'1 lo90b`var'_`wt'1 h, bcolor(gs12) clw(medthin medthin)) ///
      (scatter b`var'_`wt'1 h, c(l ) clp(l ) ms(i ) clc(black) mc(black) clw(medthick)) if h<=2013, ///
         title("`var'") xtitle("year") yline(0, lcolor(red)) legend(off) name(`var'_`wt')
	  
	}
	
	
}


graph combine ARRA_Obligations_u ARRA_Outlays_u Total_Highway_Spending_u Highway_Employment_u
*  iscale(1) ysize(4) xsize(7)
