* graphsirfs_neo.do

* Graphing Neoclassical IRFs for government consumption vs. investment
* Valerie Ramey program for "The Macroeconomic Consequences of Infrastructure Investment"
* Nov. 10, 2020

* Requires: Simulation_irfs.xlsx, which contains simulation results from Dynare programs

clear all

capture log close

set more 1

set scheme s1color


scalar theta_gc = 0.05
scalar theta_gi_theta05 = 0.05
scalar theta_gi_theta10 = 0.1

foreach siml in gc gi_theta05 gi_theta10 {

  clear
  
  import excel Simulation_irfs.xlsx, first sheet("neo_`siml'")

  sort h
  
  keep if h<25

*  tsset h, q
  
  scalar y_ss = y
  
  gen g = gc + gi
  scalar g_ss = g
  
  * for multipliers
  
  gen ydiffss = y - y_ss
  gen gdiffss = g - g_ss
  
 
  gen grossr = 1/0.99 if h==0
  replace grossr = (c[_n+1]/c)/0.99 if h>0
  
  gen grossrproduct = grossr if h==0
  
  gen r = 400*(grossr - 1)
  scalar r_ss = r
  
  gen r_`siml' = r - r_ss
  
  forvalues i = 1/24 { 
    replace grossrproduct = grossr*grossrproduct[_n-1] if h==`i'	
  }
  
  gen ydiffss_pdv = ydiffss/grossrproduct
  gen gdiffss_pdv = gdiffss/grossrproduct
    
  gen mult_int_`siml' = sum(ydiffss)/sum(gdiffss)
  gen mult_pdv_`siml' = sum(ydiffss_pdv)/sum(gdiffss_pdv)
  
  scalar cons_ss = c
  gen cdiffss = c - cons_ss
  
  gen cdiffss_pdv_`siml' = cdiffss/grossrproduct
  
  gen w = 0.64*y/n
  
  * All as % of y_ss
  foreach var in y c i gc gi kg k {
  
  scalar `var'_ss = `var'
  
  * for IRFs
  quietly replace `var' = 100*((`var' - `var'_ss)/y_ss)
  rename `var' `var'_`siml'
  
 }
 
 * not as a % of y_ss
 foreach var in n w {
 
 scalar `var'_ss = `var' 
  * for IRFs
  quietly replace `var' = 100*((`var' - `var'_ss)/`var'_ss)
  rename `var' `var'_`siml' 
 }
 
 tempfile z`siml'
  save `z`siml''
  
}
clear

use `zgc'

merge 1:1 h using `zgi_theta05', nogen
sort h
merge 1:1 h using `zgi_theta10', nogen
sort h
*merge 1:1 h using `zgi_theta05_delays', nogen
*sort h
*merge 1:1 h using `zgi_theta10_delays', nogen
*sort h


***** FIGURE 1 Baseline Neoclassical

  tw scatter gc_gc gi_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Government Spending", size(medsmall)) ///
   ylabel(0 .5 1) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(ggraph)

 tw scatter y_gc y_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Output", size(medsmall)) ///
   ylabel(0 .25 .5) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(ygraph)
 
 tw scatter c_gc c_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Private Consumption", size(medsmall)) ///
   ylabel(-.3 -.2 -.1 0) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(cgraph)
   
 tw scatter n_gc n_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Labor Input", size(medsmall)) ///
   ylabel(0 .4 .8) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(ngraph) 
   
tw scatter i_gc i_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Private Investment", size(medsmall)) ///
   ylabel(-.4  -.2 0) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(igraph) 
  
 tw scatter w_gc w_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Wage", size(medsmall)) ///
   ylabel(-.3 -.2 -.1 0) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(wgraph)
   
tw scatter r_gc r_gi_theta05  h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Real Interest Rate", size(medsmall)) ///
   ylabel(0 .02 .04 .06) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(rgraph)
  
tw scatter kg_gc kg_gi_theta05 h if h<=16, c(l l l) clp(l - -) ms(i i o) ///
   clc(black blue green) mc(black blue green) title("Public Capital", size(medsmall)) ///
   ylabel(0 5 10) ///
   legend(off) yline(0,lc(red)) xtitle("quarter") ytitle("percent") name(kggraph) 
 
  
 *graph combine ggraph ygraph cgraph ngraph igraph kggraph, col(2) iscale(0.8) ysize(5) xsize(4)
 *Manuscript
   graph combine ggraph ygraph cgraph igraph ngraph wgraph rgraph kggraph, col(2) iscale(0.7) ysize(5) xsize(4)


 